@@ -109,7 +109,7 @@ class JsonLibABC(ABC):
 
     @staticmethod
     @abstractmethod
-    def loads(string: str, **kwargs: Any) -> Any:
+    def loads(string: Union[str, bytes], **kwargs: Any) -> Any:
         ...
 
     @staticmethod
@@ -130,6 +130,18 @@ class JsonLibABC(ABC):
     def has_orjson() -> bool:
         return orjson is not None
 
+    @staticmethod
+    @abstractmethod
+    def jsoncp(
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> Any:
+        ...
+
 
 class JSON_STDLIB(JsonLibABC):
     lib = 'json'
@@ -178,13 +190,34 @@ class JSON_STDLIB(JsonLibABC):
         ).encode()
 
     @staticmethod
-    def loads(string: str, **kwargs: Any) -> Any:
+    def loads(string: Union[str, bytes], **kwargs: Any) -> Any:
         return pyjson.loads(string, **kwargs)
 
     @staticmethod
     def useable() -> bool:
         return True
 
+    @staticmethod
+    @abstractmethod
+    def jsoncp(
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> Any:
+        return JSON_STDLIB.loads(
+            JSON_STDLIB.dumps(
+                data,
+                pretty=pretty,
+                sort_keys=sort_keys,
+                append_newline=append_newline,
+                default=default or _json_encode_default,
+                **kwargs,
+            )
+        )
+
 
 class ORJSON(JsonLibABC):
     lib = 'orjson'
@@ -230,13 +263,34 @@ class ORJSON(JsonLibABC):
         )
 
     @staticmethod
-    def loads(string: str, **kwargs: Any) -> Any:
+    def loads(string: Union[str, bytes], **kwargs: Any) -> Any:
         return orjson.loads(string)
 
     @staticmethod
     def useable() -> bool:
         return JsonLibABC.has_orjson()
 
+    @staticmethod
+    @abstractmethod
+    def jsoncp(
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> Any:
+        return ORJSON.loads(
+            ORJSON.dumpb(
+                data,
+                pretty=pretty,
+                sort_keys=sort_keys,
+                append_newline=append_newline,
+                default=default or _json_encode_default,
+                **kwargs,
+            )
+        )
+
 
 class RAPIDJSON(JsonLibABC):
     lib = 'rapidjson'
@@ -287,13 +341,34 @@ class RAPIDJSON(JsonLibABC):
         ).encode()
 
     @staticmethod
-    def loads(string: str, **kwargs: Any) -> Any:
+    def loads(string: Union[str, bytes], **kwargs: Any) -> Any:
         return rapidjson.loads(string, **kwargs)
 
     @staticmethod
     def useable() -> bool:
         return JsonLibABC.has_rapidjson()
 
+    @staticmethod
+    @abstractmethod
+    def jsoncp(
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> Any:
+        return RAPIDJSON.loads(
+            RAPIDJSON.dumps(
+                data,
+                pretty=pretty,
+                sort_keys=sort_keys,
+                append_newline=append_newline,
+                default=default or _json_encode_default,
+                **kwargs,
+            )
+        )
+
 
 def pick_lib() -> 'Type[JsonLibABC]':
     if ORJSON.useable():
@@ -383,7 +458,7 @@ class JsonLib:
             **kwargs,
         )
 
-    def loads(self, string: str, **kwargs: Any) -> Any:
+    def loads(self, string: Union[str, bytes], **kwargs: Any) -> Any:
         return self._jsonlib.loads(string, **kwargs)
 
     def use_orjson(self) -> None:
@@ -401,6 +476,24 @@ class JsonLib:
     def which(self) -> str:
         return self._jsonlib.lib
 
+    def jsoncp(
+        self,
+        data: Any,
+        pretty: bool = False,
+        sort_keys: bool = False,
+        append_newline: bool = False,
+        default: Optional[Callable[[Any], Any]] = None,
+        **kwargs: Any,
+    ) -> Any:
+        return self._jsonlib.jsoncp(
+            data=data,
+            pretty=pretty,
+            sort_keys=sort_keys,
+            append_newline=append_newline,
+            default=default,
+            **kwargs,
+        )
+
 
 JSONLIB: Type[JsonLibABC] = import_json()
 
@@ -445,6 +538,24 @@ def loads(string: str, **kwargs: Any) -> Any:
     return JSONLIB.loads(string, **kwargs)
 
 
+def jsoncp(
+    data: Any,
+    pretty: bool = False,
+    sort_keys: bool = False,
+    append_newline: bool = False,
+    default: Optional[Callable[[Any], Any]] = None,
+    **kwargs: Any,
+) -> Any:
+    return JSONLIB.jsoncp(
+        data=data,
+        pretty=pretty,
+        sort_keys=sort_keys,
+        append_newline=append_newline,
+        default=default,
+        **kwargs,
+    )
+
+
 def use_orjson() -> None:
     global JSONLIB
     JSONLIB = _import_orjson()
